@@ -753,7 +753,7 @@ public class DBWriter {
 					"keyname='" + process.getKeyName() + "'," +
 					"exe='" + process.getExe() + "'," +
 					"args='" + process.getArgs().replaceAll("'", "''") + "'," +
-					"description='" + process.getDescription() + "'," +
+					"description='" + process.getDescription().replaceAll("'", "''") + "'," +
 					"type='" + process.getType() + "'," +
 					"startTime='" + BiomajUtils.dateToString(process.getStart(), Locale.US) + "',";
 
@@ -1008,26 +1008,29 @@ public class DBWriter {
 	
 	public static int getBankOwnerId(String bankName) {
 		File file = BankFactory.getBankPath(bankName);
+		int id = SQLConnectionFactory.getDefaultAdminId();
+		
 		if (file == null)
-			return 1;
+			return id;
 		
 		String path = file.getAbsolutePath();
 		String np = path.substring(0, path.lastIndexOf('/'));
 		String user = np.substring(np.lastIndexOf('/') + 1);
 		
-		int id = 1;
-		String query = "SELECT iduser FROM bw_user WHERE login='" + user + "'";
-		Statement stat = connection.getStatement();
-		try {
-			ResultSet rs = connection.executeQuery(query, stat);
-			if (rs.next()) {
-				id = rs.getInt(1);
+		if (!user.equals("db_properties")) {
+			String query = "SELECT iduser FROM bw_user WHERE login='" + user + "'";
+			Statement stat = connection.getStatement();
+			try {
+				ResultSet rs = connection.executeQuery(query, stat);
+				if (rs.next()) {
+					id = rs.getInt(1);
+				}
+			} catch (SQLException ex) {
+				SQLConnectionFactory.closeConnection(stat);
+				ex.printStackTrace();
 			}
-		} catch (SQLException ex) {
 			SQLConnectionFactory.closeConnection(stat);
-			ex.printStackTrace();
 		}
-		SQLConnectionFactory.closeConnection(stat);
 		
 		return id;
 		
