@@ -42,10 +42,7 @@
 package org.inria.biomaj.ant.task;
 
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.util.Properties;
 import java.util.Vector;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -57,8 +54,8 @@ import org.apache.tools.ant.taskdefs.ExecuteWatchdog;
 import org.apache.tools.ant.taskdefs.LogStreamHandler;
 import org.apache.tools.ant.types.Commandline;
 import org.inria.biomaj.exe.bank.BankFactory;
+import org.inria.biomaj.exe.bank.BiomajBank;
 import org.inria.biomaj.singleton.BiomajInformation;
-import org.inria.biomaj.singleton.BiomajLogger;
 import org.inria.biomaj.utils.BiomajBuildException;
 import org.inria.biomaj.utils.BiomajConst;
 import org.inria.biomaj.utils.BiomajException;
@@ -78,9 +75,6 @@ public class BmajExecute extends BmajTask {
 	public static final String DEPENDANCE_FILTER     = "__depends___";
 	public static final String DEPENDANCE_VOLATILE__FILTER     = "__depends___volatile___";
 
-	/** Property file to get information about current process */
-	private static final String FILE_PROCESS_INFORMATION=BiomajUtils.getBiomajRootDirectory()+"/log/processOn";
-
 	public static final String PROPERTY_ERROR = "biomaj.error.during.script";
 	public static final String MESSAGE_PROPERTY_ERROR = "biomaj.error.message.during.script";
 
@@ -89,6 +83,8 @@ public class BmajExecute extends BmajTask {
 	public static final String RELEASE_ALL_UNCOMPRESSED_FILES_LIST = "RELEASE_ALL_UNCOMPRESSED_FILES_LIST";
 	public static final String RELEASE_OLD_FILES_LIST ="RELEASE_OLD_FILES_LIST"; 
 	public static final String RELEASE_NEW_FILES_LIST = "RELEASE_NEW_FILES_LIST";
+	
+	public static final String CLUSTER_EXE = "biomaj_drmaa.pl";
 
 	/* Attributs Task*/
 	/* --------------*/
@@ -128,6 +124,8 @@ public class BmajExecute extends BmajTask {
 	 */
 	private String killAllOnError;
 
+	private String cluster; // If true, execute process on cluster
+	
 	private String timeOut;
 
 	long valueTimeOut = -1 ;
@@ -144,6 +142,12 @@ public class BmajExecute extends BmajTask {
 	@Override
 	public void execute() throws BuildException {
 		verifAttributs();
+		
+		String clustValue;
+		boolean runOnCluster = false;
+		if ((clustValue = this.getProject().getProperty(cluster)) != null) {
+			runOnCluster = clustValue.equals("true");
+		}
 
 		Commandline cmd = new Commandline();
 
@@ -155,15 +159,23 @@ public class BmajExecute extends BmajTask {
 		
 		Execute execute = new Execute(new LogStreamHandler(this, Project.MSG_INFO,Project.MSG_ERR), watchTimeout);
 
-		String executable = this.getProject().getProperty(exe).trim();
+		String executable = "";
 		try {
-			executable = getPathExe(getProject(),executable);
-
-			cmd.setExecutable(executable);
 			String newArgs = replacePropertiesValues(this.getProject().getProperty(args));
+			String pathToExe = getPathExe(getProject(), this.getProject().getProperty(exe).trim());
+			
+			if (runOnCluster) {
+				executable = BiomajInformation.getInstance().getProperty(BiomajInformation.PROCESSDIR) + "/" + CLUSTER_EXE;
+				newArgs = (pathToExe + " " + newArgs).trim();
+			} else {
+				executable = pathToExe;
+			}
+			
+			
+			cmd.setExecutable(executable);
 			cmd.createArgument().setLine(newArgs);
 			execute.setCommandline(cmd.getCommandline());
-
+			
 			Vector<String> listEnvironmentVariables = new Vector<String>();
 			listEnvironmentVariables.add("dbname="+getProject().getProperty(BiomajConst.dbNameProperty));
 			listEnvironmentVariables.add("datadir="+getProject().getProperty(BiomajConst.dataDirProperty));
@@ -176,6 +188,25 @@ public class BmajExecute extends BmajTask {
 			listEnvironmentVariables.add("mailadmin="+getProject().getProperty(BiomajConst.mailAdminProperty));
 			listEnvironmentVariables.add("mailsmtp="+getProject().getProperty(BiomajConst.mailSmtpHostProperty));
 			listEnvironmentVariables.add("mailfrom="+getProject().getProperty(BiomajConst.mailFromProperty));
+			
+			// Bank dependencies
+			if (getProject().getProperty("db.source") != null) {
+				String[] dependencies = BiomajUtils.getBankDependencies(getProject());
+				for (String dependency : dependencies) {
+					BankFactory factory = new BankFactory();
+					BiomajBank bb = factory.createBank(dependency, false);
+					String version = bb.getPropertiesFromBankFile().getProperty(BiomajConst.versionDirProperty);
+					String dataDir = bb.getPropertiesFromBankFile().getProperty(BiomajConst.dataDirProperty);
+					File prod = new File(dataDir + "/" + version + "/" + BiomajConst.futureReleaseLink);
+					if (!prod.exists()) {
+						prod = new File(dataDir + "/" + version + "/" + BiomajConst.currentLink);
+					}
+					String prodPath = prod.getCanonicalPath();
+					listEnvironmentVariables.add(dependency + "source=" + prodPath);
+					log("Computed bank specific variable : " + dependency + "source=" + prodPath, Project.MSG_DEBUG);
+				}
+			}
+			
 			//Nouvelles Variables d'environnements
 
 			listEnvironmentVariables.add("PATH_PROCESS_BIOMAJ="+BiomajInformation.getInstance().getProperty(BiomajInformation.PROCESSDIR));
@@ -330,23 +361,6 @@ public class BmajExecute extends BmajTask {
 
 	}
 
-	public static Properties getInfoLastProcesses(String metaProcess) {
-		Properties informationFile = new Properties();
-		try {
-			informationFile.load(new FileInputStream(new File(getNameFileInformationProcess(metaProcess))));
-		} catch (FileNotFoundException fnot) {
-			BiomajLogger.getInstance().log(fnot);
-		} catch (IOException ioe) {
-			BiomajLogger.getInstance().log(ioe);
-		}
-		return informationFile;
-	}
-
-	private static String getNameFileInformationProcess(String metaProcess) {
-		return FILE_PROCESS_INFORMATION+metaProcess+".properties";
-	}
-
-
 	static public String getPathExe(Project p,String executable) throws BiomajException {
 		if (executable.charAt(0)!='/') {
 			String scriptsDirectory = BiomajInformation.getInstance().getProperty(BiomajInformation.PROCESSDIR)+"/";
@@ -463,6 +477,14 @@ public class BmajExecute extends BmajTask {
 	public void setType(String type) {
 		this.type = type;
 	}
+	
+	public void setCluster(String cluster) {
+		this.cluster = cluster;
+	}
+	
+	public String getCluster() {
+		return cluster;
+	}
 
 
 	/**
